1.1.2. altimetry.tools Module — altimetry tools 0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- altimetry tools 0 documentation »
- 1. Description of the modules »

# 1.1.2. altimetry.tools Module

This module contain a number of tools for processing the data.

These are :

- 1.1.2.1. Spectral analysis
  - 1.1.2.1.1. About spectral analysis
  - 1.1.2.1.2. List of useful functions
  - 1.1.2.1.3. Functions
- 1.1.2.2. NetCDF tools
  - 1.1.2.2.1. An easy to use wrapper to NetCDF4 package - altimetry.tools.nctools.nc
  - 1.1.2.2.2. Addionnal function

### Navigation

- index
- modules |
- next |
- previous |
- altimetry tools 0 documentation »
- 1. Description of the modules »